@@ -59,14 +59,13 @@ impl Drop for SingleSelector {
 }
 
 pub struct Selector {
-    // 128 should be fine for max io threads
-    vec: SmallVec<[SingleSelector; 128]>,
+    vec: Vec<SingleSelector>,
 }
 
 impl Selector {
     pub fn new(io_workers: usize) -> io::Result<Self> {
         let mut s = Selector {
-            vec: SmallVec::new(),
+            vec: Vec::with_capacity(io_workers),
         };
 
         for _ in 0..io_workers {
@@ -90,17 +89,17 @@ impl Selector {
         // //info!("select; timeout={:?}", timeout_ms);
 
         // Wait for epoll events for at most timeout_ms milliseconds
-        let mask = 1 << id;
+        let mask = self.vec.len() + id;
         let single_selector = unsafe { self.vec.get_unchecked(id) };
         let epfd = single_selector.epfd;
         // first register thread handle
         let scheduler = get_scheduler();
-        scheduler.workers.parked.fetch_or(mask, Ordering::Relaxed);
+        scheduler.workers.parked.fetch_or(mask as u64, Ordering::Relaxed);
 
         let n = epoll_wait(epfd, events, timeout_ms).map_err(from_nix_error)?;
 
         // clear the park stat after comeback
-        scheduler.workers.parked.fetch_and(!mask, Ordering::Relaxed);
+        scheduler.workers.parked.fetch_and((mask - self.vec.len()) as u64, Ordering::Relaxed);
 
         for event in events[..n].iter() {
             if event.data() == 0 {
