@@ -127,6 +127,16 @@ impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
         //nothing to do
     }
 
+    /// # Examples
+    ///
+    /// ```
+    /// use cogo::std::sync::{SyncBtreeMap};
+    ///
+    /// let map = SyncBtreeMap::new();
+    /// map.insert(1, "a");
+    /// assert_eq!(*map.get(&1).unwrap(), "a");
+    /// assert_eq!(map.get(&2).is_none(), true);
+    /// ```
     pub fn get<Q: ?Sized>(&self, k: &Q) -> Option<SyncMapRef<'_, V>>
         where
             K: Borrow<Q> + std::cmp::Ord,
@@ -199,6 +209,15 @@ impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
             }
         }
     }
+
+    pub fn into_iter(self) -> Iter<'static, K, V> {
+        unsafe {
+            let iter = (&*self.read.get()).iter();
+            Iter {
+                inner: Some(iter)
+            }
+        }
+    }
 }
 
 pub unsafe fn change_lifetime_const<'a, 'b, T>(x: &'a T) -> &'b T {
@@ -344,21 +363,14 @@ impl<'a, K, V> IntoIterator for &'a mut SyncMapImpl<K, V> where K: Eq + Hash + C
     }
 }
 
-impl<'a, K, V> IntoIterator for SyncMapImpl<K, V> {
-    type Item = (K, V);
-    type IntoIter = IntoIter<K, V>;
+impl<K, V> IntoIterator for SyncMapImpl<K, V> where
+    K: Eq + Hash + Clone,
+    K: 'static, V: 'static {
+    type Item = (&'static K, &'static V);
+    type IntoIter = Iter<'static, K, V>;
 
     fn into_iter(mut self) -> Self::IntoIter {
-        loop {
-            match self.dirty.into_inner() {
-                Ok(v) => {
-                    return v.into_iter();
-                }
-                Err(e) => {
-                    self.dirty = Mutex::new(e.into_inner());
-                }
-            }
-        }
+        self.into_iter()
     }
 }
 
@@ -413,32 +425,4 @@ mod test {
             assert_eq!(*v, 2);
         }
     }
-
-    #[test]
-    pub fn test_smoke() {
-        let wait1 = WaitGroup::new();
-        let m1 = Arc::new(SyncBtreeMap::<i32, i32>::new());
-        for i in 0..100 {
-            let wg = wait1.clone();
-            let m = m1.clone();
-            go!(move ||{
-                let insert = m.insert(1, 2);
-                let g = m.get(&1).unwrap();
-                assert_eq!(2, *g.deref());
-                drop(wg);
-                println!("done{}",i);
-            });
-        }
-        for i in 0..100 {
-            let wg = wait1.clone();
-            let m = m1.clone();
-            go!(move ||{
-                let g = m.get(&2);
-                assert_eq!(None, g);
-                drop(wg);
-                println!("done remove {}",i);
-            });
-        }
-        wait1.wait();
-    }
 }
\ No newline at end of file
